@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # coding: utf-8
 
-# In[560]:
+# In[14]:
 
 
 try:
@@ -12,10 +12,10 @@ except:
         pass
 
 
-# In[559]:
+# In[15]:
 
 
-version = '0.99'
+version = '0.100'
 
 import re
 import tempfile
@@ -33,7 +33,7 @@ import time
 
 # # Helper Functions
 
-# In[427]:
+# In[16]:
 
 
 def is_testing():
@@ -43,7 +43,7 @@ def is_testing():
         return False
 
 
-# In[428]:
+# In[17]:
 
 
 def isnotebook():
@@ -54,7 +54,7 @@ def isnotebook():
     return False
 
 
-# In[429]:
+# In[18]:
 
 
 def testPrint(*args):
@@ -64,7 +64,7 @@ def testPrint(*args):
 
 # # Inspect
 
-# In[430]:
+# In[19]:
 
 
 import inspect
@@ -76,7 +76,7 @@ def debugFunctionName():
     return inspect.stack()[1][3]
 
 
-# In[431]:
+# In[20]:
 
 
 debugGetFileName(), debugGetLineNumber(), debugFunctionName()
@@ -84,7 +84,7 @@ debugGetFileName(), debugGetLineNumber(), debugFunctionName()
 
 # # Shell
 
-# In[432]:
+# In[21]:
 
 
 def shell(cmd):
@@ -97,7 +97,7 @@ def shell(cmd):
     return out
 
 
-# In[433]:
+# In[22]:
 
 
 shell_template = """/bin/bash << EOF 2>&1
@@ -119,13 +119,13 @@ def bash(cmd, lineList=True):
 
 # # Timing
 
-# In[434]:
+# In[23]:
 
 
 timeSinceLastCallDict = {}
 
 
-# In[435]:
+# In[24]:
 
 
 def timeSinceLastCall(name):
@@ -138,14 +138,14 @@ def timeSinceLastCall(name):
     return name + ": " + time_s
 
 
-# In[436]:
+# In[25]:
 
 
 if is_testing():
     print(timeSinceLastCall('test marker'))
 
 
-# In[437]:
+# In[26]:
 
 
 import time
@@ -173,7 +173,7 @@ if is_testing():
 
 # # Requiremtns
 
-# In[438]:
+# In[27]:
 
 
 requirements = []
@@ -205,7 +205,7 @@ import yaml
 
 # # Strings
 
-# In[439]:
+# In[28]:
 
 
 def sFloat0(f): return "{:0.0f}".format(f)
@@ -235,7 +235,7 @@ if is_testing():
     print(sFloatSci5(1.234567))
 
 
-# In[440]:
+# In[29]:
 
 
 def strUuid4():
@@ -246,14 +246,14 @@ def strUuid4():
     return uuid
 
 
-# In[441]:
+# In[30]:
 
 
 if is_testing():
     print(strUuid4())
 
 
-# In[442]:
+# In[31]:
 
 
 def strRand(n, num=True, upperCase=True, lowerCase=True):
@@ -265,7 +265,7 @@ def strRand(n, num=True, upperCase=True, lowerCase=True):
     return ''.join(random.choice(pool) for _ in range(n))
 
 
-# In[443]:
+# In[32]:
 
 
 if is_testing():
@@ -274,7 +274,7 @@ if is_testing():
     print(strRand(20, upperCase=False, lowerCase=False))
 
 
-# In[444]:
+# In[33]:
 
 
 def strMd5Pickle4(obj):
@@ -284,14 +284,14 @@ def strMd5Pickle4(obj):
     return md5.hexdigest()
 
 
-# In[445]:
+# In[34]:
 
 
 if is_testing():
     print(strMd5Pickle4(['a', 'b']))
 
 
-# In[446]:
+# In[35]:
 
 
 def strMd5String(s):
@@ -300,7 +300,7 @@ def strMd5String(s):
     return md5.hexdigest()
 
 
-# In[447]:
+# In[36]:
 
 
 if is_testing():
@@ -309,7 +309,7 @@ if is_testing():
 
 # # Multiprocess / Thread
 
-# In[448]:
+# In[37]:
 
 
 def mapThread(func, args, n=8):
@@ -334,14 +334,14 @@ if is_testing():
 
 # # Lists
 
-# In[449]:
+# In[38]:
 
 
 def liChunks(l, chunk_size):
     return [l[i:i + chunk_size] for i in range(0, len(l), chunk_size)]
 
 
-# In[450]:
+# In[39]:
 
 
 if is_testing():
@@ -350,7 +350,7 @@ if is_testing():
     print(liChunks(['a', 'b', 'c', 'd', 'e', 'f'], 3))
 
 
-# In[451]:
+# In[40]:
 
 
 def liSplit(a, number_of_splits):
@@ -358,7 +358,7 @@ def liSplit(a, number_of_splits):
     return [a[start:end] for start, end in zip(idxs[:-1], idxs[1:])]
 
 
-# In[452]:
+# In[41]:
 
 
 if is_testing():
@@ -370,7 +370,7 @@ if is_testing():
     print(liSplit(['a', 'b', 'c', 'd', 'e'], 6))
 
 
-# In[453]:
+# In[42]:
 
 
 def liJoin(l):
@@ -380,14 +380,14 @@ def liJoin(l):
     return out
 
 
-# In[454]:
+# In[43]:
 
 
 if is_testing():
     print(liJoin([['a', 'b', 'c'], ['d', 'e', 'f']]))
 
 
-# In[455]:
+# In[44]:
 
 
 def liFlatten(l):
@@ -404,7 +404,7 @@ def liFlatten(l):
         return l
 
 
-# In[456]:
+# In[45]:
 
 
 if is_testing():
@@ -414,7 +414,7 @@ if is_testing():
 
 # # List of Strings
 
-# In[457]:
+# In[46]:
 
 
 regex_cache = {}
@@ -424,35 +424,35 @@ def sListFilter(l, re_include=".*", re_exclude='^\b$'):
     return [e for e in l if regex_cache[re_include].search(e) and not regex_cache[re_exclude].search(e)]
 
 
-# In[458]:
+# In[47]:
 
 
 if is_testing():
     sListFilter(['good x', 'other good x', 'without the letter before y'])
 
 
-# In[459]:
+# In[48]:
 
 
 if is_testing():
     print(sListFilter(['good x', 'other good x', 'without the letter before y'], re_include='x'))
 
 
-# In[460]:
+# In[49]:
 
 
 if is_testing():
     print(sListFilter(['not enough x', 'enough xx', 'enough xx and also z'], re_include='xx+'))
 
 
-# In[461]:
+# In[50]:
 
 
 if is_testing():
     print(sListFilter(['not enough x', 'enough xx', 'enough xx and also z'], re_include='xx+', re_exclude='z'))
 
 
-# In[462]:
+# In[51]:
 
 
 def lCsv(l, force_oneline=False):
@@ -468,21 +468,21 @@ def lCsv(l, force_oneline=False):
     return ", ".join([str(e) for e in l])
 
 
-# In[463]:
+# In[52]:
 
 
 if is_testing():
     print(lCsv(['a', 'b', 1, 3.14]))
 
 
-# In[464]:
+# In[53]:
 
 
 if is_testing():
     print(lCsv([['a', 'b'], 1, 3.14]))
 
 
-# In[465]:
+# In[54]:
 
 
 if is_testing():
@@ -491,7 +491,7 @@ if is_testing():
 
 # # Text files
 
-# In[466]:
+# In[55]:
 
 
 def txtread(path):
@@ -512,7 +512,7 @@ def txtwrite(path, txt):
             return f.write(txt)
 
 
-# In[467]:
+# In[56]:
 
 
 if is_testing():
@@ -521,21 +521,21 @@ if is_testing():
 
 # # YAML files
 
-# In[468]:
+# In[57]:
 
 
 def yamlwrite(path, obj):
     txtwrite(path, yaml.dump(obj))
 
 
-# In[469]:
+# In[58]:
 
 
 def yamlread(path):
     return yaml.safe_load(txtread(path=path))
 
 
-# In[470]:
+# In[59]:
 
 
 if is_testing():
@@ -548,7 +548,7 @@ if is_testing():
 
 # # List of Strings
 
-# In[471]:
+# In[60]:
 
 
 regex_cache = {}
@@ -560,35 +560,35 @@ def sListFilter(listOfStrings, re_include=".*", re_exclude='^\b$'):
 
 # ### Examples
 
-# In[472]:
+# In[61]:
 
 
 if is_testing():
     print(sListFilter(['good x', 'other good x', 'without the letter before y']))
 
 
-# In[473]:
+# In[62]:
 
 
 if is_testing():
     print(sListFilter(['good x', 'other good x', 'without the letter before y'], re_include='x'))
 
 
-# In[474]:
+# In[63]:
 
 
 if is_testing():
     print(sListFilter(['not enough x', 'enough xx', 'enough xx and also z'], re_include='xx+'))
 
 
-# In[475]:
+# In[64]:
 
 
 if is_testing():
     print(sListFilter(['not enough x', 'enough xx', 'enough xx and also z'], re_include='xx+', re_exclude='z'))
 
 
-# In[476]:
+# In[65]:
 
 
 if is_testing():
@@ -597,7 +597,7 @@ if is_testing():
 
 # # GCP Google Cloud Platform
 
-# In[477]:
+# In[66]:
 
 
 import warnings
@@ -621,7 +621,7 @@ def _gsBlob(path):
     return blob
 
 
-# In[478]:
+# In[67]:
 
 
 def gsGsToHttp(path):
@@ -631,7 +631,7 @@ def gsHttpToGs(path):
     return path.replace("https://storage.cloud.google.com/", "gs://").split("?")[0] # "?" is for possible "?authuser=0"
 
 
-# In[479]:
+# In[68]:
 
 
 def gsLs(path):
@@ -641,7 +641,7 @@ def gsLs(path):
     return ['gs://' + bucket + '/' + blob.name for blob in client.list_blobs(prefix=prefix)]
 
 
-# In[480]:
+# In[69]:
 
 
 def gsExists(path):
@@ -651,7 +651,7 @@ def gsExists(path):
     return client.blob(prefix).exists()
 
 
-# In[481]:
+# In[70]:
 
 
 def gsUploadFile(gsPath, path):
@@ -659,7 +659,7 @@ def gsUploadFile(gsPath, path):
     blob.upload_from_filename(path)
 
 
-# In[482]:
+# In[71]:
 
 
 def gsTxtread(path):
@@ -671,7 +671,7 @@ def gsTxtread(path):
     return blob.download_as_string().decode()
 
 
-# In[483]:
+# In[72]:
 
 
 def gsTxtwrite(path, s):
@@ -679,7 +679,7 @@ def gsTxtwrite(path, s):
     return blob.upload_from_string(s)
 
 
-# In[484]:
+# In[73]:
 
 
 def gsImwrite(path, img):
@@ -688,7 +688,7 @@ def gsImwrite(path, img):
     blob.upload_from_string(encimg.tobytes())
 
 
-# In[485]:
+# In[74]:
 
 
 def gsImread(path):
@@ -697,7 +697,7 @@ def gsImread(path):
     return cv2.imdecode(raw, 1)[:, :, [2, 1, 0]]
 
 
-# In[486]:
+# In[75]:
 
 
 def gsPklWrite(path, obj):
@@ -705,7 +705,7 @@ def gsPklWrite(path, obj):
     return blob.upload_from_string(pickle.dumps(obj, protocol=4))
 
 
-# In[487]:
+# In[76]:
 
 
 def gsPklRead(path):
@@ -715,7 +715,7 @@ def gsPklRead(path):
 
 # # Pickle
 
-# In[488]:
+# In[77]:
 
 
 def pklwrite(path, obj):
@@ -728,7 +728,7 @@ def pklwrite(path, obj):
             return pickle.dump(obj, f, protocol=4)
 
 
-# In[489]:
+# In[78]:
 
 
 def pklread(path):
@@ -739,7 +739,7 @@ def pklread(path):
             return pickle.load(f)
 
 
-# In[490]:
+# In[79]:
 
 
 if is_testing():
@@ -752,7 +752,7 @@ if is_testing():
 
 # # Images
 
-# In[491]:
+# In[80]:
 
 
 def _imreadSsh(path):
@@ -819,7 +819,7 @@ def impad(img, top=0, bottom=0, left=0, right=0, color=255, mode='constant'):
         raise RuntimeError(f"Mode '{mode}' not found")
 
 
-# In[492]:
+# In[81]:
 
 
 def imscaleNN(img, s):
@@ -831,7 +831,7 @@ def imscaleBic(img, s):
 
 
 
-# In[493]:
+# In[82]:
 
 
 def imshow(array, scale=1, force_nb=False):
@@ -846,14 +846,14 @@ def imshow(array, scale=1, force_nb=False):
         cv2.waitKey()
 
 
-# In[494]:
+# In[83]:
 
 
 def imNewNoise(height, width, scaleNN=1):
     return imscaleNN((255 * np.random.rand(height, width, 3)).astype(np.uint8), scaleNN)
 
 
-# In[495]:
+# In[84]:
 
 
 if is_testing():
@@ -861,7 +861,7 @@ if is_testing():
     imshow(impad(img, bottom=10, right=10, mode='reflect'))
 
 
-# In[496]:
+# In[85]:
 
 
 def imCropUniformBorder(img, color=255):
@@ -900,7 +900,7 @@ if is_testing():
                         raise RuntimeError('Crop did not work for ', i, j, k, l)
 
 
-# In[497]:
+# In[86]:
 
 
 def imDecodeBytes(imBytes):
@@ -911,7 +911,7 @@ def imDecodeBytes(imBytes):
     return img
 
 
-# In[498]:
+# In[87]:
 
 
 #if is_testing():
@@ -919,14 +919,14 @@ def imDecodeBytes(imBytes):
 #    imshow(img)
 
 
-# In[499]:
+# In[88]:
 
 
 #if is_testing():
 #    imshow('http://via.placeholder.com/70.png')
 
 
-# In[500]:
+# In[89]:
 
 
 if is_testing():
@@ -945,7 +945,7 @@ if is_testing():
         imshow(out_large_interbic)
 
 
-# In[501]:
+# In[90]:
 
 
 def imRepeat(img, height, width):
@@ -959,7 +959,7 @@ def imRepeat(img, height, width):
     return img
 
 
-# In[502]:
+# In[91]:
 
 
 if is_testing():
@@ -967,33 +967,33 @@ if is_testing():
     imshow(imRepeat(img_random_color_3x5, 7, 11), scale=10)
 
 
-# In[503]:
+# In[92]:
 
 
 def imNewWhite(height, width):
     return np.ones((height, width, 3)).astype(np.uint8) * 255
 
 
-# In[504]:
+# In[93]:
 
 
 if is_testing(): imshow(imNewWhite(10, 500) - 30)
 
 
-# In[505]:
+# In[94]:
 
 
 def imNewBlack(height, width):
     return np.zeros((height, width, 3)).astype(np.uint8)
 
 
-# In[506]:
+# In[95]:
 
 
 if is_testing(): imshow(imNewBlack(10, 500))
 
 
-# In[507]:
+# In[96]:
 
 
 def imAddNoiseGauss(img, std):
@@ -1005,7 +1005,7 @@ def imAddNoiseGauss(img, std):
 if is_testing(): imshow(imAddNoiseGauss(imNewWhite(150, 150), 30))
 
 
-# In[508]:
+# In[97]:
 
 
 if is_testing():
@@ -1013,7 +1013,7 @@ if is_testing():
     imshow('/tmp/img.jpg')
 
 
-# In[509]:
+# In[98]:
 
 
 def imJpgDegradation(img, quality):
@@ -1026,7 +1026,7 @@ def imJpgDegradation(img, quality):
 #if is_testing(): imshow(imJpgDegradation(imread('http://via.placeholder.com/150.png'), 15))
 
 
-# In[510]:
+# In[99]:
 
 
 def imCropCenter(img, size):
@@ -1041,35 +1041,35 @@ def imCropCenter(img, size):
     return img[h_start:h_end, w_start:w_end]
 
 
-# In[511]:
+# In[100]:
 
 
 #if is_testing(): 
 #    imshow(imCropCenter(imread('http://via.placeholder.com/40.png'), 10))
 
 
-# In[512]:
+# In[101]:
 
 
 #if is_testing(): 
 #    imshow(imCropCenter(imread('http://via.placeholder.com/40.png'), 49))
 
 
-# In[513]:
+# In[102]:
 
 
 #if is_testing(): 
 #    imshow(imCropCenter(imread('http://via.placeholder.com/40.png'), 50))
 
 
-# In[514]:
+# In[103]:
 
 
 #if is_testing(): 
 #    imshow(imCropCenter(imread('http://via.placeholder.com/40.png'), 100))
 
 
-# In[515]:
+# In[104]:
 
 
 def imCropRandom(img, size, auto_size=True):
@@ -1092,7 +1092,7 @@ def imCropRandom(img, size, auto_size=True):
     return img[h_start:h_end, w_start:w_end]
 
 
-# In[516]:
+# In[105]:
 
 
 #if is_testing(): 
@@ -1102,7 +1102,7 @@ def imCropRandom(img, size, auto_size=True):
 #    imshow(imCropRandom(imread('http://via.placeholder.com/40.png'), 41))
 
 
-# In[517]:
+# In[106]:
 
 
 def imGallery(imgs, pad=0, n_cols=None, n_rows=None):
@@ -1146,7 +1146,7 @@ def imGallery(imgs, pad=0, n_cols=None, n_rows=None):
     return out
 
 
-# In[518]:
+# In[107]:
 
 
 if is_testing():
@@ -1154,7 +1154,7 @@ if is_testing():
     listOfDummyImagesBlackToWhite = [imNewBlack(10, 10) + 25 * i for i in range(10)]
 
 
-# In[519]:
+# In[108]:
 
 
 if is_testing():
@@ -1168,7 +1168,7 @@ if is_testing():
     imshow(imGallery(listOfDummyImagesBlackToWhite[:10], pad=1, n_rows=2))
 
 
-# In[520]:
+# In[109]:
 
 
 #if is_testing():
@@ -1176,7 +1176,7 @@ if is_testing():
 #    imshow(imGallery([img40x20, img40x20, img40x20], pad=1))
 
 
-# In[521]:
+# In[110]:
 
 
 def imAddTextHeader(img, text, h=None, size=None):
@@ -1213,7 +1213,7 @@ if is_testing():
 
 # # Video
 
-# In[522]:
+# In[111]:
 
 
 #def imgsToVid(imgs, file_name='out.avi'):
@@ -1233,13 +1233,13 @@ if is_testing():
 #imgsToVid(frames, 'test.avi')
 
 
-# In[523]:
+# In[112]:
 
 
 #ffmpeg -framerate 1/5 -i img%03d.png -c:v libx264 -r 30 -pix_fmt yuv420p out.mp4
 
 
-# In[524]:
+# In[113]:
 
 
 def imsToMp4(path, imgs, time_per_image, frame_rate_output_video=30, verbose=0):
@@ -1259,7 +1259,7 @@ if is_testing():
 
 # # pytorch
 
-# In[525]:
+# In[114]:
 
 
 def ptT(img_np_uint8):
@@ -1276,7 +1276,7 @@ def ptUint8(img_tensor):
     
 
 
-# In[526]:
+# In[115]:
 
 
 if is_testing():
@@ -1288,7 +1288,7 @@ if is_testing():
 
 # # Files
 
-# In[527]:
+# In[116]:
 
 
 def _fiFindByWildcardSsh(wildcard):
@@ -1309,7 +1309,26 @@ def fiFindImgs(dir_path, recursive=False, ext='png'):
     return fiFindByWildcard(wildcard)
 
 
-# In[528]:
+# In[117]:
+
+
+import os
+from os.path import join as pjoin
+from os.path import dirname as pdirname
+from os.path import basename as pfilename
+def pfilenameNoExt(p):
+    splits = pfilename(p).split('.')
+    assert len(splits) <= 2
+    return splits[0]
+
+if is_testing():
+    print(pjoin('/tmp/', 'file.txt'))
+    print(pdirname('/tmp/file.txt'))
+    print(pfilename('/tmp/file.txt'))
+    print(pfilenameNoExt('/tmp/file.txt'))
+
+
+# In[118]:
 
 
 if is_testing():
@@ -1338,7 +1357,7 @@ if is_testing():
         imshow(imGallery(imgs))
 
 
-# In[529]:
+# In[119]:
 
 
 def fiRemove(path):
@@ -1366,7 +1385,7 @@ def fiAgeHours(path):
     return (time.time() - os.stat(path)[stat.ST_MTIME]) / 3600
 
 
-# In[530]:
+# In[120]:
 
 
 if is_testing():
@@ -1398,7 +1417,7 @@ if is_testing():
         print("files: " + "\n".join(fiFindByWildcard(os.path.join(d, "**", "*"))))
 
 
-# In[531]:
+# In[121]:
 
 
 def fiUnzip(zip_path, out_dir=None, remove=False):
@@ -1413,7 +1432,7 @@ def fiUnzip(zip_path, out_dir=None, remove=False):
         zip.extractall(out_dir)
 
 
-# In[532]:
+# In[122]:
 
 
 def fiJoin(*args):
@@ -1425,7 +1444,7 @@ if is_testing():
 
 # # Jupyter
 
-# In[533]:
+# In[123]:
 
 
 def jnSettings():
@@ -1436,7 +1455,7 @@ if is_testing():
     jnSettings()
 
 
-# In[534]:
+# In[124]:
 
 
 def jnNbFullWidth():
@@ -1450,7 +1469,7 @@ def jnPandasSettings():
     pd.set_option('display.max_colwidth', 100000)
 
 
-# In[535]:
+# In[125]:
 
 
 def jnImageRenderingPixelated():
@@ -1462,7 +1481,7 @@ def jnImageRenderingAuto():
     display(HTML('<style type = text/css> img { image-rendering: auto; } </style>'))
 
 
-# In[536]:
+# In[126]:
 
 
 def jnDefault():
@@ -1480,7 +1499,7 @@ if is_testing():
 
 
 
-# In[537]:
+# In[127]:
 
 
 def jnHtmlRow(strList, width=100):
@@ -1493,7 +1512,7 @@ if is_testing():
     
 
 
-# In[538]:
+# In[128]:
 
 
 def jnImgToHtmlB64(img):
@@ -1528,7 +1547,7 @@ def jnImageRow(imgs, names=None, width=100, external=False, title_img=None, titl
     display(HTML(html))
 
 
-# In[539]:
+# In[129]:
 
 
 if is_testing():
@@ -1536,7 +1555,7 @@ if is_testing():
    
 
 
-# In[540]:
+# In[130]:
 
 
 if is_testing():
@@ -1546,7 +1565,7 @@ if is_testing():
     jnImageRow(imgs, external=True, title='test')
 
 
-# In[541]:
+# In[131]:
 
 
 
@@ -1556,7 +1575,7 @@ if is_testing():
 
 # # GIT
 
-# In[542]:
+# In[132]:
 
 
 def gitGetHash():
@@ -1566,7 +1585,7 @@ if is_testing():
     print(gitGetHash())
 
 
-# In[543]:
+# In[133]:
 
 
 def gitGetBranch():
@@ -1576,7 +1595,7 @@ if is_testing():
     print(gitGetBranch())
 
 
-# In[544]:
+# In[134]:
 
 
 def gitGetMessage():
@@ -1586,7 +1605,7 @@ if is_testing():
     print(gitGetMessage())
 
 
-# In[545]:
+# In[135]:
 
 
 def gitGetAllFiles():
@@ -1596,7 +1615,7 @@ if is_testing():
     print(gitGetAllFiles())
 
 
-# In[546]:
+# In[136]:
 
 
 def gitListByTime(path=None):
@@ -1612,7 +1631,7 @@ if is_testing():
     print(gitListByTime()[-3:])
 
 
-# In[547]:
+# In[137]:
 
 
 def gitTime(path):
@@ -1623,7 +1642,7 @@ if is_testing():
     print(gitTime("__init__.py"))
 
 
-# In[548]:
+# In[138]:
 
 
 def gitTimeRaw(path):
@@ -1634,7 +1653,7 @@ if is_testing():
     print(gitTimeRaw("__init__.py"))
 
 
-# In[549]:
+# In[139]:
 
 
 def shellSortDirsBySize():
@@ -1646,14 +1665,14 @@ if is_testing():
 
 # # Package Files
 
-# In[550]:
+# In[140]:
 
 
 if is_testing():
     package_files = {}
 
 
-# In[551]:
+# In[141]:
 
 
 def shell(cmd):
@@ -1661,7 +1680,7 @@ def shell(cmd):
     return result.stdout.decode()
 
 
-# In[552]:
+# In[142]:
 
 
 if is_testing():
@@ -1693,7 +1712,7 @@ setup(
 )""".format(requirements=", ".join(["'" + r + "'" for r in requirements]), version=version)
 
 
-# In[553]:
+# In[143]:
 
 
 if is_testing():
@@ -1703,7 +1722,7 @@ description-file = README.md
 """
 
 
-# In[554]:
+# In[144]:
 
 
 if is_testing():
@@ -1726,14 +1745,14 @@ OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE."""
 
 
-# In[555]:
+# In[145]:
 
 
 if is_testing():
     package_files['README.md'] = ""
 
 
-# In[556]:
+# In[ ]:
 
 
 if is_testing():
@@ -1744,7 +1763,7 @@ if is_testing():
     print(output.strip(), 'Version correct: ', output.strip() == version, "(", output.strip(), version, ")")
 
 
-# In[557]:
+# In[147]:
 
 
 if is_testing():
@@ -1755,7 +1774,7 @@ lx/__init__.py
 """
 
 
-# In[558]:
+# In[148]:
 
 
 if is_testing():
